@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 use constant { border => 1000000 };
 
@@ -29,6 +29,7 @@ use Time::Piece;
 my $t = localtime;
 
 has price => ( is => 'rw', isa => 'Int', default => 0 );
+has amount => ( is => 'rw', isa => 'Int', default => 1 );
 has date => ( is => 'rw', isa => 'Str', default => $t->ymd() );
 has no_wh => ( is => 'ro', isa => 'Bool', default => 0 );
 
@@ -42,12 +43,12 @@ sub net {
 
 sub tax {
     my $self = shift;
-    return int( $self->price() * $consumption{'rate'} );
+    return int( $self->price() * $consumption{'rate'} ) * $self->amount();
 }
 
 sub full {
     my $self = shift;
-    return int( $self->price() + $self->tax() );
+    return int( $self->price() * $self->amount() + $self->tax() );
 }
 
 sub withholding {
@@ -55,20 +56,20 @@ sub withholding {
     return 0 if $self->no_wh();
     my $rate = $self->rate();
     if( $self->price() <= border ) {
-        return int( $self->price() * $rate );
+        return int( $self->price() * $rate ) * $self->amount();
     }else{
         my $base = $self->price() - border;
         
-        return int( $base * $rate * 2 + border * $rate );
+        return int( $base * $rate * 2 + border * $rate ) * $self->amount();
     }
 }
 
 sub rate {
     my $self = shift;
     my $rate = $withholding{'rate'};
-    my $from = $t->strptime( $special{'from'}, '%Y-%m-%d');
-    my $until = $t->strptime( $special{'until'}, '%Y-%m-%d');
-    my $date = $t->strptime( $self->date(), '%Y-%m-%d');
+    my $from = $t->strptime( $special{'from'}, '%Y-%m-%d' );
+    my $until = $t->strptime( $special{'until'}, '%Y-%m-%d' );
+    my $date = $t->strptime( $self->date(), '%Y-%m-%d' );
 
     return $rate if $date < $from or $until < $date;
     return $rate + $special{'rate'};
@@ -77,7 +78,6 @@ sub rate {
 sub total {
     my $self = shift;
     return $self->full - $self->withholding;
-
 }
 
 1;
@@ -134,7 +134,7 @@ Business::Tax::Withholding::JP は日本のビジネスで長期的に使える
  
 =head2 Constructor
 
-=head3 new( price => I<Int>, date => I<Date>, no_wh => I<Bool> );
+=head3 new( price => I<Int>, amount => I<Int>, date => I<Date>, no_wh => I<Bool> );
 
 You can omit these paramators.
 
@@ -144,10 +144,16 @@ You can omit these paramators.
  
 =item price
  
-price of your products will be set. defaults 0.
+the price of your products will be set. defaults 0.
  
 税抜価格を指定してください。指定しなければ0です。
+
+=item amount
  
+the amount of your products will be set. defaults 1.
+ 
+数量を指定してください。指定しなければ1です。
+
 =item date
 
 You can set payday. the net of withholding depends on this. default is today.
@@ -172,6 +178,12 @@ You can reset the price.
 
 price に値を代入可能です。
  
+=item amount
+ 
+You can reset the amount.
+ 
+amount に値を代入可能です。
+
 =item date
 
 You can reset the payday like 'YYYY-MM-DD'
